summaryrefslogtreecommitdiff
path: root/sql/sql_lex.h
diff options
context:
space:
mode:
authorunknown <kostja@bodhi.local>2006-10-23 11:51:45 +0400
committerunknown <kostja@bodhi.local>2006-10-23 11:51:45 +0400
commit07cf5b9bd349f799bc0e81caf79edfbd29fd0512 (patch)
tree8975cf9bcdde83b55d94ab5299cb5d61a93acb9c /sql/sql_lex.h
parent8db4dc3f91dfbe03181e63ed45bdf35a5d65aeb0 (diff)
parent133e91aa89e05437158946c0a3b7f7d2f27a0f6d (diff)
downloadmariadb-git-07cf5b9bd349f799bc0e81caf79edfbd29fd0512.tar.gz
Merge bk-internal.mysql.com:/home/bk/mysql-5.0
into bodhi.local:/opt/local/work/mysql-5.0-runtime-merge mysql-test/t/func_gconcat.test: Auto merged sql/item_func.cc: Auto merged sql/sql_base.cc: Auto merged sql/sql_insert.cc: Auto merged sql/sql_lex.cc: Auto merged sql/sql_lex.h: Auto merged sql/sql_select.cc: Auto merged sql/sql_update.cc: Auto merged mysql-test/r/view.result: Manual merge. mysql-test/t/view.test: Manual merge.
Diffstat (limited to 'sql/sql_lex.h')
-rw-r--r--sql/sql_lex.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/sql/sql_lex.h b/sql/sql_lex.h
index 378f968118e..1db62cde5ee 100644
--- a/sql/sql_lex.h
+++ b/sql/sql_lex.h
@@ -530,7 +530,8 @@ public:
list during split_sum_func
*/
uint select_n_having_items;
- uint cond_count; /* number of arguments of and/or/xor in where/having */
+ uint cond_count; /* number of arguments of and/or/xor in where/having/on */
+ uint between_count; /* number of between predicates in where/having/on */
enum_parsing_place parsing_place; /* where we are parsing expression */
bool with_sum_func; /* sum function indicator */
/*